@@ -1,27 +1,51 @@
 package XS::Log;
-#Build  MD5 : /+2rdJW+zbQ5F6M9/fr5Yw
-#Build Time : 2025-09-18 18:46:21
-our $VERSION = 1.05;
-our $BUILDDATE = "2025-09-18";  #Build Time: 18:46:21
+#Build  MD5 : 247/pl1Xcz3CA4JSyzAy3g
+#Build Time : 2025-09-19 17:22:30
+our $VERSION = 1.06;
+our $BUILDDATE = "2025-09-19";  #Build Time: 17:22:30
 use strict;
 use warnings;
+use constant { 
+    #颜色设置
+    LOG_LEVEL_OFF		=> 0,		# 关闭日志
+	LOG_LEVEL_FATAL		=> 1,    	# 严重错误
+	LOG_LEVEL_ERROR		=> 2,    	# 错误信息
+	LOG_LEVEL_WARN		=> 3,    	# 警告信息
+	LOG_LEVEL_INFO		=> 4,    	# 一般信息
+    LOG_LEVEL_TRACE		=> 5,    	# 最详细的日志信息
+    LOG_LEVEL_DEBUG		=> 6,    	# 调试信息
+	LOG_LEVEL_TEXT		=> 7,    	# 原文输出
+    LOG_MODE_CYCLE		=> 0,
+	LOG_MODE_DAILY		=> 1,
+	LOG_MODE_HOURLY		=> 2,
+    LOG_TARGET_CONSOLE	=> 0x01,
+	LOG_TARGET_FILE		=> 0x02,
+	LOG_TARGET_SYSLOG	=> 0x04
+};
 use XSLoader;
 require Exporter;
 our @ISA = qw(Exporter);
 
 our @EXPORT_OK = qw(
     openLog closeLog flushLog setLogOptions setLogColor setLogMode setLogTargets setLogLevel
-    printNote printBug printInf printWarn printErr printFail printText
-    LOG_LEVEL_OFF LOG_LEVEL_FATAL LOG_LEVEL_ERROR LOG_LEVEL_WARN LOG_LEVEL_INFO
-    LOG_LEVEL_TRACE LOG_LEVEL_DEBUG LOG_LEVEL_TEXT
-    LOG_MODE_CYCLE LOG_MODE_DAILY LOG_MODE_HOURLY
-    LOG_TARGET_CONSOLE LOG_TARGET_FILE LOG_TARGET_SYSLOG
+    log_write printNote printBug printInf printWarn printErr printFail printLog
+	LOG_LEVEL_OFF LOG_LEVEL_FATAL LOG_LEVEL_ERROR LOG_LEVEL_WARN LOG_LEVEL_INFO LOG_LEVEL_TRACE LOG_LEVEL_DEBUG LOG_LEVEL_TEXT
+	LOG_MODE_CYCLE LOG_MODE_DAILY LOG_MODE_HOURLY 
+	LOG_TARGET_CONSOLE LOG_TARGET_FILE LOG_TARGET_SYSLOG
 );
 # 定义导出标签 :all
 our %EXPORT_TAGS = (
     all => \@EXPORT_OK,
 );
 XSLoader::load('XS::Log', $VERSION);
+
+sub printNote {my ($fmt, @args) = @_;my $msg = sprintf($fmt, @args);my ($pkg, $file, $line) = caller;log_write(LOG_LEVEL_TRACE,$file, $line,$msg);}
+sub printBug  {my ($fmt, @args) = @_;my $msg = sprintf($fmt, @args);my ($pkg, $file, $line) = caller;log_write(LOG_LEVEL_DEBUG,$file, $line,$msg);}
+sub printInf  {my ($fmt, @args) = @_;my $msg = sprintf($fmt, @args);my ($pkg, $file, $line) = caller;log_write(LOG_LEVEL_INFO, $file, $line,$msg);}
+sub printWarn {my ($fmt, @args) = @_;my $msg = sprintf($fmt, @args);my ($pkg, $file, $line) = caller;log_write(LOG_LEVEL_WARN, $file, $line,$msg);}
+sub printErr  {my ($fmt, @args) = @_;my $msg = sprintf($fmt, @args);my ($pkg, $file, $line) = caller;log_write(LOG_LEVEL_ERROR,$file, $line,$msg);}
+sub printFail {my ($fmt, @args) = @_;my $msg = sprintf($fmt, @args);my ($pkg, $file, $line) = caller;log_write(LOG_LEVEL_FATAL,$file, $line,$msg);}
+sub printLog  {my ($fmt, @args) = @_;my $msg = sprintf($fmt, @args);my ($pkg, $file, $line) = caller;log_write(LOG_LEVEL_TEXT, $file, $line,$msg);}
 1;
 
 __END__
@@ -60,6 +84,7 @@ B<XS::Log>是高效快速的日志模块，纯c语言开发，快速高效的IO
  
  openLog("test.log", \%opt);
  
+ printLog($msg);                    #原文输出
  printInf("This is info");
  printWarn("This is warning");
  printErr("This is error");
@@ -173,7 +198,7 @@ B<XS::Log>是高效快速的日志模块，纯c语言开发，快速高效的IO
   printErr($msg);
   printFail($msg);              #注意：谨慎使用，会直接exit退出程序
   printNote($msg);
-  printText($msg);              #原文输出
+  printLog($msg);               #原文输出
 
   printInf("%s\n",$msg);        #支持：%的方式格式化输出
 
@@ -242,7 +267,7 @@ B<XS::Log>是高效快速的日志模块，纯c语言开发，快速高效的IO
    show_timestamp    => 1,
    show_log_level    => 1,
    show_file_info    => 0,
-   max_file_size     => 1024*1024*10,		                       #LOG_MODE_CYCLE 有效
+   max_file_size     => 1024*1024*10,                              #LOG_MODE_CYCLE 有效
    max_files         => 5,                                         #LOG_MODE_CYCLE 有效
    flush_immediately => 1,
   );
